Documentation
¶
Index ¶
- func NewAddonConfigInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewAddonInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewClusterInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredAddonConfigInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredAddonInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredKubermaticSettingInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredProjectInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredUserInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredUserProjectBindingInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredUserSSHKeyInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewKubermaticSettingInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewProjectInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewUserInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewUserProjectBindingInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewUserSSHKeyInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type AddonConfigInformer
- type AddonInformer
- type ClusterInformer
- type Interface
- type KubermaticSettingInformer
- type ProjectInformer
- type UserInformer
- type UserProjectBindingInformer
- type UserSSHKeyInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewAddonConfigInformer ¶
func NewAddonConfigInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewAddonConfigInformer constructs a new informer for AddonConfig type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewAddonInformer ¶
func NewAddonInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewAddonInformer constructs a new informer for Addon type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewClusterInformer ¶
func NewClusterInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterInformer constructs a new informer for Cluster type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredAddonConfigInformer ¶
func NewFilteredAddonConfigInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredAddonConfigInformer constructs a new informer for AddonConfig type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredAddonInformer ¶
func NewFilteredAddonInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredAddonInformer constructs a new informer for Addon type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterInformer ¶
func NewFilteredClusterInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterInformer constructs a new informer for Cluster type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredKubermaticSettingInformer ¶
func NewFilteredKubermaticSettingInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredKubermaticSettingInformer constructs a new informer for KubermaticSetting type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredProjectInformer ¶
func NewFilteredProjectInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredProjectInformer constructs a new informer for Project type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredUserInformer ¶
func NewFilteredUserInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredUserInformer constructs a new informer for User type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredUserProjectBindingInformer ¶
func NewFilteredUserProjectBindingInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredUserProjectBindingInformer constructs a new informer for UserProjectBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredUserSSHKeyInformer ¶
func NewFilteredUserSSHKeyInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredUserSSHKeyInformer constructs a new informer for UserSSHKey type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewKubermaticSettingInformer ¶
func NewKubermaticSettingInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewKubermaticSettingInformer constructs a new informer for KubermaticSetting type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewProjectInformer ¶
func NewProjectInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewProjectInformer constructs a new informer for Project type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewUserInformer ¶
func NewUserInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewUserInformer constructs a new informer for User type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewUserProjectBindingInformer ¶
func NewUserProjectBindingInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewUserProjectBindingInformer constructs a new informer for UserProjectBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewUserSSHKeyInformer ¶
func NewUserSSHKeyInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewUserSSHKeyInformer constructs a new informer for UserSSHKey type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type AddonConfigInformer ¶
type AddonConfigInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.AddonConfigLister
}
AddonConfigInformer provides access to a shared informer and lister for AddonConfigs.
type AddonInformer ¶
type AddonInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.AddonLister
}
AddonInformer provides access to a shared informer and lister for Addons.
type ClusterInformer ¶
type ClusterInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.ClusterLister
}
ClusterInformer provides access to a shared informer and lister for Clusters.
type Interface ¶
type Interface interface {
// Addons returns a AddonInformer.
Addons() AddonInformer
// AddonConfigs returns a AddonConfigInformer.
AddonConfigs() AddonConfigInformer
// Clusters returns a ClusterInformer.
Clusters() ClusterInformer
// KubermaticSettings returns a KubermaticSettingInformer.
KubermaticSettings() KubermaticSettingInformer
// Projects returns a ProjectInformer.
Projects() ProjectInformer
// Users returns a UserInformer.
Users() UserInformer
// UserProjectBindings returns a UserProjectBindingInformer.
UserProjectBindings() UserProjectBindingInformer
// UserSSHKeys returns a UserSSHKeyInformer.
UserSSHKeys() UserSSHKeyInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type KubermaticSettingInformer ¶
type KubermaticSettingInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.KubermaticSettingLister
}
KubermaticSettingInformer provides access to a shared informer and lister for KubermaticSettings.
type ProjectInformer ¶
type ProjectInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.ProjectLister
}
ProjectInformer provides access to a shared informer and lister for Projects.
type UserInformer ¶
type UserInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.UserLister
}
UserInformer provides access to a shared informer and lister for Users.
type UserProjectBindingInformer ¶
type UserProjectBindingInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.UserProjectBindingLister
}
UserProjectBindingInformer provides access to a shared informer and lister for UserProjectBindings.
type UserSSHKeyInformer ¶
type UserSSHKeyInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.UserSSHKeyLister
}
UserSSHKeyInformer provides access to a shared informer and lister for UserSSHKeys.